@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 import matplotlib.pyplot as plt
 
-__all__ = ["nice"]
+__all__ = ["ggplot"]
 
-def nice():
+def ggplot():
     """Set my preferred style: The ggplot style"""
     plt.style.use("ggplot")
\ No newline at end of file
